User Guide
==========

.. automodule:: resfo_utilities

Corner-point Grid
-----------------

.. automodule:: resfo_utilities._cornerpoint_grid

.. autoclass:: resfo_utilities.CornerpointGrid
   :members:
   :no-index:

.. autoclass:: resfo_utilities.MapAxes
   :members:
   :no-index:

Summaries
---------

.. automodule:: resfo_utilities._summary_reader

.. autoclass:: resfo_utilities.SummaryReader
   :members:
   :no-index:

.. autoclass:: resfo_utilities.SummaryKeyword
   :members:
   :no-index:

RFT
---

.. automodule:: resfo_utilities._rft_reader

.. autoclass:: resfo_utilities.RFTEntry
   :members:
   :no-index:

.. autoclass:: resfo_utilities.RFTReader
   :members:
   :no-index:

Summarykeys
------------

.. automodule:: resfo_utilities._summary_keys

.. autofunction:: resfo_utilities.make_summary_key
   :no-index:

.. autoclass:: resfo_utilities.SummaryKeyType
   :members:
   :no-index:

.. autofunction:: resfo_utilities.is_rate
   :no-index:

.. autofunction:: resfo_utilities.history_key
   :no-index:
